
#include "lcd.h"
#include "compiler.h"
#include "GenericTypeDefs.h"

// Define a fast instruction execution time in terms of loop time
// typically > 43us
#define	LCD_F_INSTR		10

// Define a slow instruction execution time in terms of loop time
// typically > 1.35ms
#define	LCD_S_INSTR		150

// Define the startup time for the LCD in terms of loop time
// typically > 30ms
#define	LCD_STARTUP		2000


#define		_LCD_IDLE(__cnt)	_uLCDstate = 1; _uLCDloops = __cnt;
#define		_LCD_INIT(__cnt)	_uLCDstate++; _uLCDloops = __cnt;


unsigned int	_uLCDloops;
unsigned char	_uLCDstate;
unsigned char 	_uLCDchar;

/*****************************************************************************
 * Function: LCDProcessEvents
 *
 * Preconditions: None.
 *
 * Overview: This is a state mashine to issue commands and data to LCD. Must be
 * called periodically to make LCD message processing.
 *
 * Input: None.
 *
 * Output: None.
 *
 *****************************************************************************/
void LCDProcessEvents(void)
{
	switch (_uLCDstate) {
		case 1:								// *** wait *** 
			if (_uLCDloops) _uLCDloops--;
			else _uLCDstate = 0;
			break;
		case 2:								// *** init ***
			PMCON = 0x83BF;				    // Setup the PMP
			PMMODE = 0x3FF;
			PMAEN = 0x0001;
			PMADDR = 0x0000;
			_uLCDstate = 64;				// Set the next state
			_uLCDloops = LCD_STARTUP;		// Set the entry delay
			break;
		case 3:								// *** put ***
			_LCD_IDLE(LCD_F_INSTR);
			PMADDR = 0x0001;
			PMDIN1 = _uLCDchar;
			break;
		case 4:								// *** clear ***
			_LCD_IDLE(LCD_S_INSTR);
			PMADDR = 0x0000;
			PMDIN1 = 0b00000001;
			break;
		case 5:								// *** home ***
			_LCD_IDLE(LCD_S_INSTR);
			PMADDR = 0x0000;
			PMDIN1 = 0b00000010;
			break;	
		case 6:								// *** command ***
			_LCD_IDLE(LCD_F_INSTR);
			PMADDR = 0x0000;
			PMDIN1 = _uLCDchar;
			break;

		// This is the LCD init state machine
		case 64:							// Standard delay states for the init
		case 66:
		case 68:
		case 70:							// Programmable delay loop
			if (_uLCDloops) _uLCDloops--;
			else _uLCDstate++;
			break;
		case 65:
			_LCD_INIT(LCD_F_INSTR);
			PMDIN1 = 0b00111100;			// Set the default function
			break;
		case 67:
			_LCD_INIT(LCD_F_INSTR);
			PMDIN1 = 0b00001100;            // Set the display control
			break;
		case 69:	
			_LCD_INIT(LCD_S_INSTR);
			PMDIN1 = 0b00000001;			// Clear the display
			break;
		case 71:
			_LCD_INIT(LCD_S_INSTR);
			PMDIN1 = 0b00000110;			// Set the entry mode
			break;
		case 72:
			_uLCDstate = 0;
			break;
		default:
			_uLCDstate = 0;
			break;
	}
}
/*****************************************************************************
 * EOF
 *****************************************************************************/
