
#include "spi.h"
//SPI setup for PIC24 differs from that of PIC18 processor, so separate routines are written for these cases
#if defined(__18F87J11)
//for PIC18s
void SPIPut(BYTE v)
{
		//Reset the Global interrupt pin
    SSPIF = 0;
    do
    {
        WCOL = 0;
		//Reset write collision bit
        SSPBUF = v;
		//load the buffer
    } while( WCOL );
		//perform write again if write collision occurs
    while( SSPIF == 0 );
		//Wait until interrupt is received from the MSSP module
	SSPIF = 0;
		//Reset the interrupt
}

BYTE SPIGet(void)
{
    SPIPut(0x00);
		//write a dummy value to read the data from the other SPI module
    return SSPBUF;
		//read the SSPBUF value for data transmitted by other SSP module
}

#else
//SPI read(get) and write(put) routines for PIC24
/************************ FUNCTIONS ********************************/

/*********************************************************************
* Function:         void SPIPut(BYTE v)
*
* PreCondition:     SPI has been configured 
*
* Input:		    v - is the byte that needs to be transfered
*
* Output:		    none
*
* Side Effects:	    SPI transmits the byte
*
* Overview:		    This function will send a byte over the SPI
*
* Note:			    None
********************************************************************/
void SPIPut(BYTE v)
{
    BYTE dummy;
    
		//if not a PIC32 MCU
        IFS0bits.SPI1IF = 0;
		//Clear the SPIxIF bit in the respective IFSx register
        dummy = SPI1BUF;
		//read the value before writing to avoid overflow bit setting
        SPI1BUF = v;
		//write in to buffer the new value
        while(IFS0bits.SPI1IF == 0){}
		//wait until interrupt is set
}

/*********************************************************************
* Function:         BYTE SPIGet(void)
*
* PreCondition:     SPI has been configured 
*
* Input:		    none
*
* Output:		    BYTE - the byte that was last received by the SPI
*
* Side Effects:	    none
*
* Overview:		    This function will read a byte over the SPI
*
* Note:			    None
********************************************************************/
BYTE SPIGet(void)
{

	//for other PIC processors (PIC24, dsPIC33, dsPIC30 etc)
        SPIPut(0x00);
	//put dummy value for transmit and wait until transmit is complete
        return SPI1BUF;
	//return the SPI1BUF value to the calling function (reads the data from the other SPI device)

}

#endif
